@@ -733,7 +733,7 @@ gb_toolbar_insert_toolbar_child (GtkToolbar *toolbar,
       return;
     }
 
-  if (!gb_button_toolbar_find_child_widgets (new_child, &icon, &label))
+  if (!gb_button_toolbar_find_child_widgets (new_child, &label, &icon))
     return;
   if (GTK_IS_RADIO_BUTTON (new_child))
     type = GTK_TOOLBAR_CHILD_RADIOBUTTON;
@@ -793,7 +793,17 @@ gb_toolbar_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 
   gb_widget_write_standard_source (widget, data);
 
-  /* FIXME: GTK2 - set style & orientation. */
+  /* We have to set the style explicitly for now, as the default style depends
+     on the user's theme settings. Ideally GTK+ should have a
+     GTK_TOOLBAR_DEFAULT style. */
+  source_add (data,
+	      "  gtk_toolbar_set_style (GTK_TOOLBAR (%s), %s);\n",
+	      data->wname, style);
+
+  if (GTK_TOOLBAR (widget)->orientation != GTK_ORIENTATION_HORIZONTAL)
+    source_add (data,
+		"  gtk_toolbar_set_orientation (GTK_TOOLBAR (%s), %s);\n",
+		data->wname, orientation);
 
   if (!GTK_TOOLTIPS (GTK_TOOLBAR (widget)->tooltips)->enabled)
     source_add (data,
